@@ -6,6 +6,6 @@ LOGGER = logging.getLogger(f"mkdocs.plugins.badges")
 LOGGER.addFilter(warning_filter)
 
 # Import local files in the correct order
-from .utils import replace_regex_matches
-from .normal_badge import replace_normal_badges
+# from .utils import replace_regex_matches
+# from .normal_badge import replace_normal_badges
 from .plugin import BadgesPlugin
